@@ -1,15 +1,88 @@
 package Video::Xine;
 
-use 5.008005;
+=pod
+
+=head1 NAME
+
+Video::Xine - Perl interface to libxine
+
+=head1 SYNOPSIS
+
+  use Video::Xine;
+
+  # Create and initialize the Xine object
+  my $xine = Video::Xine->new(
+    config_file => "$ENV{'HOME'}/.xine/config",
+  );
+
+  # Load a video driver
+  my $video_driver = Video::Xine::Driver::Video->new($xine,"auto",1,$x11_visual);
+
+  # Create a new stream (put your video driver under $DRIVER)
+  my $stream = $xine->stream_new(undef,$DRIVER);
+
+  # Open a file on the stream
+  $stream->open('file://my/movie/file.avi')
+    or die "Couldn't open stream: ", $stream->get_error();
+
+  # Get the current position (0 .. 65535), position in time, and length
+  # of stream in milliseconds
+  my ($pos, $pos_time, $length_time) = $stream->get_pos_length();
+
+  # Start the stream playing
+  $stream->play()
+     or die "Couldn't play stream: ", $xine->get_error();
+
+  # Play the stream to the end
+  while ( $stream->get_status() == XINE_STATUS_PLAY ) {
+    sleep(1);
+  }
+
+
+=head1 DESCRIPTION
+
+A perl interface to Xine, the Linux movie player. More properly, an
+interface to libxine, the development library. Requires installation of
+libxine.
+
+Xine by itself does not provide a user interface, and neither does
+this interface. Instead, you must set up the window using your own
+windowing code, and pass the window information to Xine.
+
+=head2 EXPORT
+
+=head3 STATUS CONSTANTS
+
+The Status constants are the results for a get_status() call. See
+xine.h for details.
+
+=over 4
+
+=item *
+
+XINE_STATUS_STOP
+
+Indicates that the stream is stopped.
+
+=item *
+
+XINE_STATUS_PLAY
+
+Indicates that the stream is playing.
+
+=cut
+
+use 5.008003;
 use strict;
 use warnings;
 
 use Exporter;
 use Carp;
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 our @ISA = qw(Exporter);
 our @EXPORT = qw(
+  XINE_STATUS_IDLE
   XINE_STATUS_STOP
   XINE_STATUS_PLAY
 
@@ -25,6 +98,10 @@ our @EXPORT = qw(
   XINE_EVENT_UI_NUM_BUTTONS
   XINE_EVENT_SPU_BUTTON
   XINE_EVENT_DROPPED_FRAMES
+
+  XINE_GUI_SEND_DRAWABLE_CHANGED
+  XINE_GUI_SEND_EXPOSE_EVENT
+  XINE_GUI_SEND_VIDEOWIN_VISIBLE
 );
 
 require XSLoader;
@@ -32,6 +109,7 @@ XSLoader::load('Video::Xine', $VERSION);
 
 # Preloaded methods go here.
 
+use constant XINE_STATUS_IDLE => 0;
 use constant XINE_STATUS_STOP => 1;
 use constant XINE_STATUS_PLAY => 2;
 
@@ -48,6 +126,10 @@ use constant XINE_EVENT_UI_NUM_BUTTONS => 10;
 use constant XINE_EVENT_SPU_BUTTON => 11;
 use constant XINE_EVENT_DROPPED_FRAMES => 12;
 
+use constant XINE_GUI_SEND_DRAWABLE_CHANGED => 2;
+use constant XINE_GUI_SEND_EXPOSE_EVENT => 3;
+use constant XINE_GUI_SEND_VIDEOWIN_VISIBLE => 5;
+
 sub new {
   my $type = shift;
   my (%in) = @_;
@@ -118,6 +200,10 @@ sub new {
 
 }
 
+sub get_video_port {
+  $_[0]->{'video_port'};
+}
+
 sub open {
   my $self = shift;
   my ($mrl) = @_;
@@ -227,6 +313,13 @@ sub new {
   bless $self, $type;
 }
 
+sub send_gui_data {
+  my $self = shift;
+  my ($type, $data) = @_;
+
+  xine_port_send_gui_data($self->{'driver'}, $type, $data);
+}
+
 sub DESTROY {
   my $self = shift;
   xine_close_video_driver($self->{'xine'}{'xine'}, $self->{'driver'});
@@ -264,59 +357,11 @@ sub get_event {
 1;
 __END__
 
-=head1 NAME
-
-Video::Xine - Perl interface to libxine
-
-=head1 SYNOPSIS
-
-  use Video::Xine;
-
-  # Create and initialize the Xine driver
-  my $xine = $xine->new(
-    config_file => "$ENV{'HOME'}/.xine/config",
-    video_driver => Video::Xine->VIDEO_DRIVER_NULL()
-  );
-
-  # Play a particular AVI until it's over
-  my $stream = $xine->stream_new();
-  $stream->open('file://my/movie/file.avi')
-    or die "Couldn't open stream: ", $stream->get_error();
-
-  # Get the current position (0 .. 65535), position in time, and length
-  # of stream in milliseconds
-  my ($pos, $pos_time, $length_time) = $stream->get_pos_length();
-
-
-  $stream->play()
-     or die "Couldn't play stream: ", $xine->get_error();
-
-  while ( $xine->get_status() == XINE_STATUS_PLAY ) {
-    sleep(1);
-  }
-
-
-=head1 DESCRIPTION
-
-A perl interface to Xine, the Linux movie player. More properly, an
-interface to libxine, the development library.
-
-=head2 EXPORT
-
-None by default.
-
-
+=pod
 
 =head1 SEE ALSO
 
-Mention other useful documentation such as the documentation of
-related modules or operating system documentation (such as man pages
-in UNIX), or any relevant external documentation such as RFCs or
-standards.
-
-If you have a mailing list set up for your module, mention it here.
-
-If you have a web site set up for your module, mention it here.
+L<xine(1)>
 
 =head1 AUTHOR
 
